@@ -1,5 +1,6 @@
 import os
 import copy
+import warnings
 from textwrap import indent, dedent
 
 import ujson
@@ -534,9 +535,6 @@ def fetch_adjacencies(sources=None, targets=None, rois=None, min_roi_weight=1, m
     primary_totals = primary_roi_conn_df.groupby(['bodyId_pre', 'bodyId_post'])['weight'].sum().reset_index()
 
     totals_df = connections_df.merge(primary_totals, 'left', on=['bodyId_pre', 'bodyId_post'], suffixes=['_all', '_primary'])
-    print(connections_df)
-    print(primary_totals)
-    print(totals_df)
     totals_df.fillna(0, inplace=True)
     totals_df['weight_notprimary'] = totals_df.eval('weight_all - weight_primary').astype(int)
     totals_df['roi'] = 'NotPrimary'
@@ -561,15 +559,21 @@ def fetch_adjacencies(sources=None, targets=None, rois=None, min_roi_weight=1, m
                             .sum()
                             .reset_index())
     compare_df = connections_df.merge(summed_roi_weights, 'left', on=['bodyId_pre', 'bodyId_post'], suffixes=['_orig', '_summed'])
-    assert compare_df.fillna(0).eval('weight_orig == weight_summed').all()
+    compare_df = compare_df.fillna(0)[['weight_orig', 'weight_summed']]
+    mismatches = compare_df.eval('weight_orig != weight_summed')
+    if mismatches.any():
+        warnings.warn(
+            "There appears to be an inconsistency in the neuprint data.\n"
+            "Detected edge(s) in which the aggregate 'weight' does not match the sum of the roiInfo 'post' counts.\n"
+            "Please report this to the neuprint administrators.\n"
+            f"{compare_df.loc[mismatches]}"
+        )
 
     # Filter for the user's ROIs, if any
     if rois:
         roi_conn_df.query('roi in @rois and weight > 0', inplace=True)
 
     if min_total_weight >= 1:
-        print('---')
-        print(roi_conn_df)
         total_weights_df = roi_conn_df.groupby(['bodyId_pre', 'bodyId_post'])['weight'].sum().reset_index()
         keep_conns = total_weights_df.query('weight >= @min_total_weight')[['bodyId_pre', 'bodyId_post']]
         roi_conn_df = roi_conn_df.merge(keep_conns, 'inner', on=['bodyId_pre', 'bodyId_post'])
